==> 0.0.50.tar.gz: lib/widget/appbar/custom_app_bar.dart <==
import 'package:flutter/material.dart';
import 'package:sharing/widget/custom/custom_background_image.dart';
import '../../common/values/sizes.dart';
import '../../remote/model/application_config.dart';
import '../custom/custom_background_gradient.dart';
import '../custom/spaces.dart';
import '../text/custom_text_large_bold_field.dart';

class CustomAppBar extends StatefulWidget {
  final String title;
  final Widget? tabBarMenu;
  final Widget? tabBarMenuRight;
  final bool? isShowShadow;
  final ApplicationConfig? applicationConfig;
  final Widget? backgroundImage;
  final double? heightBar;

  const CustomAppBar({
    required this.title,
    this.tabBarMenu,
    this.tabBarMenuRight,
    this.isShowShadow = false,
    this.applicationConfig,
    this.backgroundImage,
    this.heightBar,
  });

  @override
  State<CustomAppBar> createState() => _CustomAppBarState();
}

class _CustomAppBarState extends State<CustomAppBar> {
  @override
  Widget build(BuildContext context) {
    return widget.backgroundImage == null
        ? CustomBackgroundGradient(
            applicationConfig: widget.applicationConfig, child: appBarBody())
        : CustomBackgroundImage(
            backgroundImage: widget.backgroundImage,
            heightBar: widget.heightBar,
            child: appBarBody());
  }

  Widget appBarBody() {
    return SafeArea(
      maintainBottomViewPadding: false,
      bottom: false,
      child: Column(
        children: [
          Container(
            child: Padding(
              padding: EdgeInsets.only(left: 20),
              child: Column(
                children: [
                  SizedBox(
                    height: Sizes.HEIGHT_52,
                    child: Row(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: <Widget>[
                        CustomTextLargeBoldField(
                          label: widget.title,
                          color: Colors.white,
                        ),
                        Padding(
                          padding: const EdgeInsets.only(right: 12),
                          child: widget.tabBarMenuRight ?? Container(),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ),
          widget.tabBarMenu ?? Container(),
          if (widget.isShowShadow == true) ...{SpaceShadowBottom()}
        ],
      ),
    );
  }
}

==> 0.0.56.tar.gz: lib/widget/appbar/custom_app_bar.dart <==
import 'package:flutter/material.dart';
import 'package:sharing/widget/custom/custom_background_image.dart';
import '../../common/values/sizes.dart';
import '../../remote/model/application_config.dart';
import '../custom/custom_background_gradient.dart';
import '../custom/spaces.dart';
import '../text/custom_text_large_bold_field.dart';

class CustomAppBar extends StatefulWidget {
  final String title;
  final Widget? tabBarMenu;
  final Widget? tabBarMenuRight;
  final bool? isShowShadow;
  final ApplicationConfig? applicationConfig;
  final Widget? backgroundImage;
  final Color? backgroundColor;
  final double? heightBar;

  const CustomAppBar({
    required this.title,
    this.tabBarMenu,
    this.tabBarMenuRight,
    this.isShowShadow = false,
    this.applicationConfig,
    this.backgroundImage,
    this.backgroundColor,
    this.heightBar,
  });

  @override
  State<CustomAppBar> createState() => _CustomAppBarState();
}

class _CustomAppBarState extends State<CustomAppBar> {
  @override
  Widget build(BuildContext context) {
    return widget.backgroundImage == null
        ? CustomBackgroundGradient(
            applicationConfig: widget.applicationConfig, child: appBarBody())
        : CustomBackgroundImage(
            backgroundColor: widget.backgroundColor,
            backgroundImage: widget.backgroundImage,
            heightBar: widget.heightBar ?? Sizes.padingTop(context) + Sizes.HEIGHT_52,
            child: appBarBody());
  }

  Widget appBarBody() {
    return SafeArea(
      maintainBottomViewPadding: false,
      bottom: false,
      child: Column(
        children: [
          Container(
            child: Padding(
              padding: EdgeInsets.only(left: 20),
              child: Column(
                children: [
                  SizedBox(
                    height: Sizes.HEIGHT_52,
                    child: Row(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: <Widget>[
                        CustomTextLargeBoldField(
                          label: widget.title,
                          color: Colors.white,
                        ),
                        Padding(
                          padding: const EdgeInsets.only(right: 12),
                          child: widget.tabBarMenuRight ?? Container(),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ),
          widget.tabBarMenu ?? Container(),
          if (widget.isShowShadow == true) ...{SpaceShadowBottom()}
        ],
      ),
    );
  }
}
